@@ -6,7 +6,10 @@
 
 #pragma once
 
+#include <KItinerary/BarcodeDecoder>
+
 #include <QDateTime>
+#include <QJSValue>
 #include <QObject>
 
 namespace KItinerary {
@@ -30,9 +33,9 @@ public:
     Q_INVOKABLE QString decodeAztec(const QVariant &img) const;
     /** Decode a Aztec barcode image containing binary data.
      *  @param img An image containing the barcode, e.g. a PdfImage instance.
-     *  @return a QByteArray, which from the JS perspective is essentially an opque handle.
+     *  @return a JS ArrayBuffer
      */
-    Q_INVOKABLE QVariant decodeAztecBinary(const QVariant &img) const;
+    Q_INVOKABLE QJSValue decodeAztecBinary(const QVariant &img) const;
     /** Decode as QR barcode image.
      *  @param img An image containing the barcode, e.g. a PdfImage instance.
      */
@@ -48,42 +51,21 @@ public:
      */
     Q_INVOKABLE QString decodeAnyBarcode(const QVariant &img) const;
 
-    /** Decode an UIC 918.3 message from a train ticket Aztec code.
-     *  @param s A QByteArray containing the raw data from the barcode.
-     *  @returns An instance of Uic9183Parser.
-     */
-    Q_INVOKABLE QVariant decodeUic9183(const QVariant &s) const;
-    /** Decode an VDV ticket barcode.
-     *  @param s A QByteArray containing the raw VDV barcode data.
-     *  @returns An instance of VdvTicket.
-     */
-    Q_INVOKABLE QVariant decodeVdvTicket(const QVariant &s) const;
     /** Decode an ERA SSB ticket barcode.
      *  @param s A QByteArray containing the raw ERA SSB barcode data.
      *  @param versionOverride Override version auto-detection. Useful for tickets that are known to
      *  fill their version field incorrectly.
      *  @returns An instance of SSBTicket.
      */
-    Q_INVOKABLE QVariant decodeEraSsbTicket(const QVariant &s, int versionOverride = 0) const;
-
-    /** Converts the given QByteArray into an base64 encoded string. */
-    Q_INVOKABLE QString toBase64(const QVariant &b) const;
-    /** Converts a given Base64 encoded string to a QByteArray. */
-    Q_INVOKABLE QVariant fromBase64(const QString &s) const;
-    /** Converts the given QByteArray into a BitArray. */
-    Q_INVOKABLE QVariant toBitArray(const QVariant &b) const;
-    /** Converts the given QByteArray into a string for processing in JS.
-     *  This only works if there isn't "too much" binary content in the byte array.
-     */
-    Q_INVOKABLE QString byteArrayToString(const QVariant &b) const;
+    Q_INVOKABLE QVariant decodeEraSsbTicket(const QByteArray &s, int versionOverride = 0) const;
 
     ///@cond internal
-    void setContextDate(const QDateTime &dt);
     void setDecoder(BarcodeDecoder *decoder);
     ///@endcond
 
 private:
-    QDateTime m_contextDate;
+    QString decodeBarcode(const QVariant &img, BarcodeDecoder::BarcodeTypes hints) const;
+
     BarcodeDecoder *m_decoder = nullptr;
 };
 
