@@ -35,6 +35,11 @@ bool PdfDocumentProcessor::canHandleData(const QByteArray &encodedData, QStringV
 
 static void applyContextDateTime(PdfDocument *pdf, ExtractorDocumentNode &node)
 {
+    // ignore broken PDF times for Amadeus documents
+    if (pdf->producer() == QLatin1String("Amadeus") && pdf->creationTime() == pdf->modificationTime() && pdf->creationTime().date() == QDate(2011, 5, 10)) {
+        return;
+    }
+
     auto dt = pdf->modificationTime();
     if (!dt.isValid()) {
         dt = pdf->creationTime();
