@@ -113,26 +113,19 @@ static bool isAirportName(const QString &name, KnowledgeDb::IataCode iataCode)
 
 static bool isPlausibeGate(const QString &s)
 {
+    if (s.isEmpty() || s.size() > 10 || s.count(QLatin1Char('-')) > 1 || s.count(QLatin1Char(' ')) > 2) {
+        return false;
+    }
     for (const auto &c : s) {
-        if (c.isLetter() || c.isDigit()) {
-            return true;
+        if (!c.isLetter() && !c.isDigit() && c != QLatin1Char(' ') && c != QLatin1Char(' ')) {
+            return false;
         }
     }
-    return false;
+    return true;
 }
 
 static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
 {
-    // "relevantDate" is the best guess for the boarding time
-    if (pass->relevantDate().isValid() && !flight.boardingTime().isValid()) {
-        const auto tz = KnowledgeDb::timezoneForAirport(KnowledgeDb::IataCode{flight.departureAirport().iataCode()});
-        if (tz.isValid()) {
-            flight.setBoardingTime(pass->relevantDate().toTimeZone(tz));
-        } else {
-            flight.setBoardingTime(pass->relevantDate());
-        }
-    }
-
     // search for missing information by field key
     const auto fields = pass->fields();
     for (const auto &field : fields) {
@@ -155,7 +148,17 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
         }
     }
 
-    // search for missing information in field content
+    // "relevantDate" is the best guess for the boarding time if we didn't find an explicit field for it
+    if (pass->relevantDate().isValid() && !flight.boardingTime().isValid()) {
+        const auto tz = KnowledgeDb::timezoneForAirport(KnowledgeDb::IataCode{flight.departureAirport().iataCode()});
+        if (tz.isValid()) {
+            flight.setBoardingTime(pass->relevantDate().toTimeZone(tz));
+        } else {
+            flight.setBoardingTime(pass->relevantDate());
+        }
+    }
+
+   // search for missing information in field content
     const auto depIata = KnowledgeDb::IataCode(flight.departureAirport().iataCode());
     const auto arrIata = KnowledgeDb::IataCode(flight.arrivalAirport().iataCode());
     const auto frontFields = frontFieldsForPass(pass);
