@@ -10,7 +10,7 @@
 #include "iso9796_2decoder_p.h"
 #include "logging.h"
 
-#include "../tlv/berelement_p.h"
+#include "../tlv/berelement.h"
 
 #include <QByteArray>
 #include <QDebug>
